<?php

namespace Slack\Blockkit\Blocks;

use \Exception;
use Illuminate\Support\Collection;
use Slack\Blockkit\Blocks;
use Slack\Blockkit\Blocks\Elements\Text;
use Slack\Blockkit\Element;

final class Actions extends Blocks
{
	protected const LIMITS = [
		'block_id' => 255,			// @todo Should be unique for each message
	];

	private const MAX_ELEMENTS = 5;

	/**
	 * @param Text $text
	 * @throws Exception
	 */
	public function __construct()
	{
		parent::__construct();

		// Defaults
		$this->type = 'actions';
	}

	public static function item(): self
	{
		return new self();
	}

	/* OPTIONAL ITEMS */

	public function block_id(string $string): self
	{
		$this->block_id = $this->validate('block_id',$string);

		return $this;
	}

	public function elements(Collection $collection): self
	{
		if (count($collection) > self::MAX_ELEMENTS)
			throw new Exception(sprintf('Can only have maximum %d elements',self::MAX_ELEMENTS));

		$this->elements = $collection;

		return $this;
	}
}